DirWorkerHandler class

Constructors

DirWorkerHandler({String appName = 'locorda', String id = directoryRemoteHandlerId})

Properties

appName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier matching the main-thread handler.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBackend(BackendWorkerHandlerContext context, SyncEngineConfig config) Future<Backend>
Creates a backend instance for this remote handler.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isPlatformSupported bool
no setter